@@ -303,12 +303,19 @@ execLdconfig() {
 
 
 
+sub ldconfigExists() {
+
+    return (system("ldconfig -? 2>/dev/null") >> 8) != 127;
+}
+
+
+
 sub
 doLdconfig() {
 #-----------------------------------------------------------------------------
 #  Run Ldconfig where appropriate.
 #-----------------------------------------------------------------------------
-    if ($OSNAME eq "linux" || system("ldconfig -? 2>/dev/null") != 127) {
+    if ($OSNAME eq "linux" || ldconfigExists()) {
         # This is a system where Ldconfig makes sense
 
         print("In order for the Netpbm shared library to be found when " .
@@ -814,7 +821,7 @@ installConfig($$$$$$$) {
 
     my $configTemplateFilename = dirname($0) . "/config_template";
 
-    my $templateOpened = open(TEMPLATE, "<", $configTemplateFilename);
+    my $templateOpened = open(TEMPLATE, "<$configTemplateFilename");
     if (!$templateOpened) {
         $error = "Can't open template file '$configTemplateFilename'.\n";
     } else {
@@ -822,7 +829,7 @@ installConfig($$$$$$$) {
 
         close(TEMPLATE);
 
-        my $versionOpened = open(VERSION, "<", "$pkgdir/VERSION");
+        my $versionOpened = open(VERSION, "<$pkgdir/VERSION");
 
         my $version;
         if (!$versionOpened) {
@@ -844,7 +851,7 @@ installConfig($$$$$$$) {
             
             my $filename = "$bindir/netpbm-config";
             
-            my $success = open(NETPBM_CONFIG, ">", $filename);
+            my $success = open(NETPBM_CONFIG, ">$filename");
             if ($success) {
                 chmod(0755, $filename);
                 foreach (@{$fileContentsR}) { print NETPBM_CONFIG; }
