@@ -43,7 +43,7 @@ struct box {
     int ury;  /* upper right Y coord */
 };
 
-struct cmdline_info {
+static struct cmdline_info {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
     */
