@@ -975,7 +975,7 @@ pm_read_unknown_size(FILE * const file,
 
 void
 pm_tell2(FILE *       const fileP, 
-         pm_filepos * const fileposP,
+         void *       const fileposP,
          unsigned int const fileposSize) {
 /*----------------------------------------------------------------------------
    Return the current file position as *filePosP, which is a buffer
@@ -992,15 +992,18 @@ pm_tell2(FILE *       const fileP,
         pm_error("ftello() to get current file position failed.  "
                  "Errno = %s (%d)\n", strerror(errno), errno);
 
-    if (fileposSize == sizeof(pm_filepos))
-        *fileposP = filepos;
-    else if (fileposSize == sizeof(long)) {
+    if (fileposSize == sizeof(pm_filepos)) {
+        pm_filepos * const fileposP_filepos = fileposP;
+        *fileposP_filepos = filepos;
+    } else if (fileposSize == sizeof(long)) {
         if (sizeof(pm_filepos) > sizeof(long) &&
             filepos >= (pm_filepos) 1 << (sizeof(long)*8))
             pm_error("File size is too large to represent in the %u bytes "
                      "that were provided to pm_tell2()", fileposSize);
-        else 
-            *(long*)fileposP = (long)filepos;
+        else {
+            long * const fileposP_long = fileposP;
+            *fileposP_long = (long)filepos;
+        }
     } else
         pm_error("File position size passed to pm_tell() is invalid: %u.  "
                  "Valid sizes are %u and %u", 
@@ -1014,7 +1017,7 @@ pm_tell(FILE * const fileP) {
     
     long filepos;
 
-    pm_tell2(fileP, (pm_filepos *)&filepos, sizeof(filepos));
+    pm_tell2(fileP, &filepos, sizeof(filepos));
 
     return filepos;
 }
